@@ -2,8 +2,8 @@ __author__ = ", ".join(["Shyue Ping Ong", "Anubhav Jain", "Geoffroy Hautier",
                         "William Davidson Richard", "Stephen Dacek",
                         "Michael Kocher", "Dan Gunter", "Shreyas Cholia",
                         "Vincent L Chevrier", "Rickard Armiento"])
-__date__ = "Aug 2 2013"
-__version__ = "2.7.8"
+__date__ = "Sep 6 2013"
+__version__ = "2.8.0"
 
 #Useful aliases for commonly used objects and modules.
 
