@@ -18,11 +18,13 @@ __status__ = "Beta"
 import itertools
 
 from pymatgen.core.composition import Composition
-from pymatgen.core.physical_constants import ELECTRON_TO_AMPERE_HOURS
+from pymatgen.core.units import Charge, Time
+from pymatgen.core.physical_constants import AVOGADROS_CONST
 from pymatgen.phasediagram.pdmaker import PhaseDiagram
 from pymatgen.phasediagram.entries import PDEntry
 from pymatgen.apps.battery.battery_abc import AbstractElectrode, \
     AbstractVoltagePair
+from pymatgen.core.periodic_table import Element
 
 
 class InsertionElectrode(AbstractElectrode):
@@ -419,6 +421,10 @@ class InsertionVoltagePair(AbstractVoltagePair):
 
         #Initialize normalization factors, charged and discharged entries
 
+        valence_list = Element(ion_sym).oxidation_states
+        working_ion_valence = max(valence_list)
+
+
         (self.framework,
          norm_charge) = frame_charge_comp.get_reduced_composition_and_factor()
         norm_discharge = \
@@ -441,10 +447,11 @@ class InsertionVoltagePair(AbstractVoltagePair):
             - (comp_charge[working_element] / norm_charge)
 
         self._voltage = \
-            ((entry_charge.energy / norm_charge) -
+            (((entry_charge.energy / norm_charge) -
              (entry_discharge.energy / norm_discharge)) / \
-            self._num_ions_transferred + working_ion_entry.energy_per_atom
-        self._mAh = self._num_ions_transferred * ELECTRON_TO_AMPERE_HOURS * 1e3
+            self._num_ions_transferred + working_ion_entry.energy_per_atom) / working_ion_valence
+        self._mAh = self._num_ions_transferred * Charge(1, "e").to("C") * \
+            Time(1, "s").to("h") * AVOGADROS_CONST * 1000 * working_ion_valence
 
         #Step 4: add (optional) hull and muO2 data
         self.decomp_e_charge = \
