@@ -9,7 +9,7 @@ __author__ = "Shyue Ping Ong, Michael Kocher"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "2.0"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
+__email__ = "shyuep@gmail.com"
 __status__ = "Production"
 __date__ = "Sep 23, 2011"
 
@@ -17,11 +17,13 @@ import os
 import re
 import json
 
+from pymatgen.core.units import Mass, Length, unitized
 from pymatgen.util.decorators import singleton, cached_class
 from pymatgen.util.string_utils import formula_double_format
 from pymatgen.serializers.json_coders import MSONable
 from functools import total_ordering
 
+
 #Loads element data from json file
 with open(os.path.join(os.path.dirname(__file__), "periodic_table.json")) as f:
     _pt_data = json.load(f)
@@ -285,30 +287,29 @@ class Element(object):
         self._z = self._data["Atomic no"]
         self._symbol = symbol
         self._x = self._data.get("X", 0)
-
-    def __getattr__(self, a):
-        if a.lower() in ["name", "atomic_mass", "atomic_radius",
-                         "mendeleev_no", "electrical_resistivity",
-                         "velocity_of_sound", "reflectivity",
-                         "refractive_index", "poissons_ratio", "molar_volume",
-                         "electronic_structure", "thermal_conductivity",
-                         "boiling_point", "melting_point",
-                         "critical_temperature", "superconduction_temperature",
-                         "liquid_range", "bulk_modulus", "youngs_modulus",
-                         "brinell_hardness", "rigidity_modulus",
-                         "mineral_hardness", "vickers_hardness",
-                         "density_of_solid", "atomic_radius_calculated",
-                         "van_der_waals_radius", "ionic_radii",
-                         "coefficient_of_linear_thermal_expansion"]:
+        for a in ["name", "mendeleev_no", "electrical_resistivity",
+                  "velocity_of_sound", "reflectivity",
+                  "refractive_index", "poissons_ratio", "molar_volume",
+                  "electronic_structure", "thermal_conductivity",
+                  "boiling_point", "melting_point",
+                  "critical_temperature", "superconduction_temperature",
+                  "liquid_range", "bulk_modulus", "youngs_modulus",
+                  "brinell_hardness", "rigidity_modulus",
+                  "mineral_hardness", "vickers_hardness",
+                  "density_of_solid", "atomic_radius_calculated",
+                  "van_der_waals_radius",
+                  "coefficient_of_linear_thermal_expansion"]:
             kstr = a.capitalize().replace("_", " ")
-            if kstr not in self._data:
-                return None
-            val = self._data[kstr]
+            val = self._data.get(kstr, None)
             if str(val).startswith("no data"):
-                return None
-            else:
-                return val
-        raise AttributeError(a)
+                val = None
+            self.__setattr__(a, val)
+        if str(self._data.get("Atomic radius",
+                              "no data")).startswith("no data"):
+            self.atomic_radius = None
+        else:
+            self.atomic_radius = Length(self._data["Atomic radius"], "ang")
+        self.atomic_mass = Mass(self._data["Atomic mass"], "amu")
 
     def __getnewargs__(self):
         #function used by pickle to recreate object
@@ -322,10 +323,11 @@ class Element(object):
         return self._data.copy()
 
     @property
+    @unitized("pm")
     def average_ionic_radius(self):
         """
-        Average ionic radius for element in pm. The average is taken over all
-        oxidation states of the element for which data is present.
+        Average ionic radius for element (with units). The average is taken
+        over all oxidation states of the element for which data is present.
         """
         if "Ionic radii" in self._data:
             radii = self._data["Ionic radii"]
@@ -334,6 +336,7 @@ class Element(object):
             return 0
 
     @property
+    @unitized("pm")
     def ionic_radii(self):
         """
         All ionic radii of the element as a dict of
