@@ -45,10 +45,6 @@ The following are conversion factors.
 .. attribute:: ELECTRON_TO_AMPERE_HOURS
 
     Conversion from electron charge to Amphere-hours
-
-.. attribute:: AMU_TO_KG
-
-    Conversion from atomic mass unit to kg
 """
 
 import numpy as _np
@@ -57,7 +53,7 @@ __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
+__email__ = "shyuep@gmail.com"
 __status__ = "Production"
 __date__ = "Sep 23, 2011"
 
@@ -67,6 +63,7 @@ __date__ = "Sep 23, 2011"
 #systems, the replication of these constants minimizes scipy dependency.
 
 ELECTRON_CHARGE = 1.602176565e-19
+ELECTRON_MASS = 9.10938291e-31
 EPSILON_0 = 8.85418781762e-12
 BOLTZMANN_CONST = 1.3806488e-23
 ELECTRON_VOLT = 1.602176565e-19
@@ -84,21 +81,15 @@ F = AVOGADROS_CONST * ELECTRON_CHARGE
 EV_PER_ATOM_TO_J_PER_MOL = ELECTRON_VOLT * AVOGADROS_CONST
 EV_PER_ATOM_TO_KJ_PER_MOL = EV_PER_ATOM_TO_J_PER_MOL / 1000
 ELECTRON_TO_AMPERE_HOURS = EV_PER_ATOM_TO_J_PER_MOL / 3600
-AMU_TO_KG = 1.660538921e-27
+RY_TO_EV = 13.605698066
+BOHR_TO_ANGS = 0.5291772083
 
-
-#: 1 Hartree, in eV
-Ha_eV = 27.21138386
-
-eV_Ha = 1./Ha_eV
-
-#: 1 Bohr, in Angstrom
-Bohr_Ang = 0.52917720859
-
-Ang_Bohr = 1./Bohr_Ang
+# 1 Hartree in eV
+HA_TO_EV = 27.21138386
+EV_TO_HA = 1./HA_TO_EV
 
 # Conversion factor eV/A**3 --> GPa
-eVA3_GPa = 160.21773
+EV_ANGS3_TO_GPA = 160.21773
 
 ###############################################################################
 # Conversion tools.
@@ -119,7 +110,7 @@ def Ha2eV(Ha):
     >>> Ha2eV([1, 2])
     array([ 27.21138386,  54.42276772])
     """
-    return _np.asanyarray(Ha) * Ha_eV
+    return _np.array(Ha) * HA_TO_EV
 
 
 def Ha2meV(Ha):
@@ -143,7 +134,7 @@ def eV2Ha(eV):
     >>> eV2Ha([ 27.21138386, 1])
     array([ 1.        ,  0.03674933])
     """
-    return _np.asanyarray(eV) / Ha_eV
+    return _np.array(eV) / HA_TO_EV
 
 
 def Bohr2Ang(Bohr):
@@ -160,7 +151,7 @@ def Bohr2Ang(Bohr):
     >>> Bohr2Ang([1, 2])
     array([ 0.52917721,  1.05835442])
     """
-    return _np.asanyarray(Bohr) * Bohr_Ang
+    return _np.array(Bohr) * BOHR_TO_ANGS
 
 
 def Ang2Bohr(Ang):
@@ -177,4 +168,4 @@ def Ang2Bohr(Ang):
     >>> Ang2Bohr(Bohr2Ang([1, 2]))
     array([ 1.,  2.])
     """
-    return _np.asanyarray(Ang) / Bohr_Ang
+    return _np.array(Ang) / BOHR_TO_ANGS
