@@ -11,12 +11,11 @@ import collections
 import numpy as np
 import os.path
 import abc
+import pymatgen.core.units as units
 
 from pprint import pformat
-
 from pymatgen.util.decorators import singleton
 from pymatgen.core.design_patterns import Enum, AttrDict
-from pymatgen.core.units import any2Ha
 from pymatgen.core.physical_constants import Ang2Bohr, Bohr2Ang
 from pymatgen.serializers.json_coders import MSONable
 from pymatgen.symmetry.finder import SymmetryFinder
@@ -135,11 +134,8 @@ class Smearing(AbivarAble, MSONable):
         return s
 
     def __eq__(self, other):
-        if other is None:
-            return False
-        else:
-            return (self.occopt == other.occopt and
-                    np.allclose(self.tsmear, other.tsmear))
+        return (self.occopt == other.occopt and 
+                np.allclose(self.tsmear, other.tsmear))
 
     def __ne__(self, other):
         return not self == other
@@ -158,7 +154,11 @@ class Smearing(AbivarAble, MSONable):
             * Smearing instance
             * "name:tsmear"  e.g. "gaussian:0.004"  (Hartree units)
             * "name:tsmear units" e.g. "gaussian:0.1 eV"
+            * None --> no smearing
         """
+        if obj is None:
+            return Smearing.nosmearing()
+
         if isinstance(obj, cls):
             return obj
 
@@ -173,8 +173,8 @@ class Smearing(AbivarAble, MSONable):
             try:
                 tsmear = float(tsmear)
             except ValueError:
-                tsmear, units = tsmear.split()
-                tsmear = any2Ha(units)(float(tsmear))
+                tsmear, unit = tsmear.split()
+                tsmear = units.Energy(float(tsmear), unit).to("Ha")
 
             return cls(occopt, tsmear)
 
@@ -349,7 +349,7 @@ def asabistructure(obj):
 
             if obj.endswith(".nc"):
                 structure = structure_from_etsf_file(obj)
-                print(structure._sites)
+                #print(structure._sites)
             else:
                 structure = read_structure(obj)
 
@@ -425,20 +425,23 @@ class AbiStructure(Structure, AbivarAble):
         for (atm_idx, site) in enumerate(self):
             typat[atm_idx] = types_of_specie.index(site.specie) + 1
 
-        significant_figures = 12
-        format_str = "{{:.{0}f}}".format(significant_figures)
-        fmt = format_str.format
+        #significant_figures = 12
+        #format_str = "{{:.{0}f}}".format(significant_figures)
+        #fmt = format_str.format
 
-        lines = []
-        for vec in Ang2Bohr(self.lattice.matrix):
-            lines.append(" ".join([fmt(c) for c in vec]))
-        rprim = "\n" + "\n".join(lines)
+        #lines = []
+        #for vec in Ang2Bohr(self.lattice.matrix):
+        #    lines.append(" ".join([fmt(c) for c in vec]))
+        #rprim = "\n" + "\n".join(lines)
 
-        lines = []
-        for (i, site) in enumerate(self):
-            coords = site.frac_coords
-            lines.append( " ".join([fmt(c) for c in coords]) + " # " + site.species_string )
-        xred = '\n' + "\n".join(lines)
+        #lines = []
+        #for (i, site) in enumerate(self):
+        #    coords = site.frac_coords
+        #    lines.append( " ".join([fmt(c) for c in coords]) + " # " + site.species_string )
+        #xred = '\n' + "\n".join(lines)
+
+        rprim = Ang2Bohr(self.lattice.matrix)
+        xred = np.reshape([site.frac_coords for site in self], (-1,3))
 
         return {
             "acell" : 3 * [1.0],
@@ -554,7 +557,7 @@ class KSampling(AbivarAble):
                 raise ValueError("For Path mode, num_kpts must be specified and >0")
 
             kptbounds = np.reshape(kpts, (-1,3,))
-            print("in path with kptbound: %s " % kptbounds)
+            #print("in path with kptbound: %s " % kptbounds)
 
             abivars.update({
                 "ndivsm"   : num_kpts,
@@ -712,7 +715,7 @@ class KSampling(AbivarAble):
             kpath_bounds = []
             for label in kpath_labels:
                 red_coord = sp.kpath["kpoints"][label]
-                print("label %s, red_coord %s" % (label, red_coord))
+                #print("label %s, red_coord %s" % (label, red_coord))
                 kpath_bounds.append(red_coord)
 
         return cls(mode     = KSampling.modes.path,
@@ -962,8 +965,8 @@ class PPModel(AbivarAble, MSONable):
             try:
                 plasmon_freq = float(plasmon_freq)
             except ValueError:
-                plasmon_freq, units = plasmon_freq.split()
-                plasmon_freq = any2Ha(units)(float(plasmon_freq))
+                plasmon_freq, unit = plasmon_freq.split()
+                plasmon_freq = units.Energy(float(plasmon_freq), unit).to("Ha")
 
         return cls(mode=mode, plasmon_freq=plasmon_freq)
 
